System.register([], (function () {
	'use strict';
	return {
		execute: (function () {

			Unknown.staticMember;
			Unknown.prototype.method;

		})
	};
}));
